@@ -106,10 +106,10 @@ groups = [
           'V',  # 0
           'B',  # 0
           'MO',  # 1
-          'ISP_OB',
-          'T_KCU',
-          'T_KCV',
-          'T_KCD',
+        #   'ISP_OB',
+        #   'T_KCU',
+        #   'T_KCV',
+        #   'T_KCD',
         #   'T_KCDV'
 ]
 
@@ -153,10 +153,10 @@ predictors = [
           'V',  # 0
           'B',  # 0
           'MO',  # 1
-          'ISP_OB',
-          'T_KCU',
-          'T_KCV',
-          'T_KCD',
+        #   'ISP_OB',
+        #   'T_KCU',
+        #   'T_KCV',
+        #   'T_KCD',
         #   'T_KCDV'
 ]
 
