@@ -1,5 +1,3 @@
-from datetime import time
-from mysqlx import DatabaseError
 import numpy as np
 import pandas as pd
 from sklearn.decomposition import PCA
@@ -78,6 +76,12 @@ def load_columns(df, output_df, groups, cols, kvr_duo_delta_columns, dim, pca):
     информация обо всех проходах будет использована в обучении модели
     и, соответственно, для предсказания.
     '''
+    duo_uss = group_starts_with['Group_ДУО_УСС_01']
+    kvr_uss = group_starts_with['Group_КВР_УСС_01']
+    for col in duo_uss+kvr_uss:
+        ind = df[df[col]<0].index
+        temp = df[col].copy()
+        df[col].loc[ind] = temp[ind]*(-1)
 
     for columns in groups:
         if isinstance(columns, list): # convolve
@@ -106,7 +110,7 @@ def time2num(df, columns, cols):
     for column in columns:
         if column in cols:
             df[column] = df[column].astype(str)
-            df[column] = df[column].apply(lambda x: np.dot(np.array(x.split(':'), dtype=float), np.array([1.0, 1.0/60, 1.0])))
+            df[column] = df[column].apply(lambda x: np.dot(np.array(x.split(':'), dtype=float), np.array([1.0, 1.0/60])))
     return
 
 
@@ -300,12 +304,14 @@ class Data_Preprocessor:
         # print('Inside preprocessing:\n', data.shape)
 
         if self.mode == 'predict':
+            data = data.astype('float64')
             data[gather(self.features)].fillna(np.nan, inplace=True)
             return data
 
         elif self.mode == 'train':
             load_targets(df, Y, {target:targets[target] for target in self.targets})
             # print('Inside preprocessing, Y = \n', Y.shape)
+            data = data.astype('float64')
 
             self.features = data.columns.values
             print(self.features)
@@ -356,7 +362,7 @@ class Data_Preprocessor:
             #-------------------------------------------------------------
 
             columns = self.features
-            self.features = list(new_X.columns)
+            self.features = list(new_X.columns.astype(str))
             # print('Feature Selector selects: ', list(new_X.columns))
 
             temp = [
@@ -375,6 +381,7 @@ class Data_Preprocessor:
             self.features = list(flatten(temp))
             print('\tself.features: ', self.features)
 
+            self.targets = [str(i) for i in self.targets]
             Y = pd.DataFrame(Y, columns=self.targets)
 
             return pd.concat([data, Y], axis=1)
